/**************************************************************************//**
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ******************************************************************************
 *
 * @file hiveconstants.h
 * @brief Provides constants necessary for library caller interaction with Hive Client
 *
 *****************************************************************************/


#ifndef __hive_constants_h__
#define __hive_constants_h__

/// Maximum length of a Hive Client error message
#define MAX_HIVE_ERR_MSG_LEN 1024
/// Maximum length of a column name
#define MAX_COLUMN_NAME_LEN  64
/// Maximum length of a column type name
#define MAX_COLUMN_TYPE_LEN  64


/* Default connection parameters */
/// Default Hive database name
static const char* DEFAULT_DATABASE = "default";
/// Default Hive Server host
static const char* DEFAULT_HOST     = "localhost";
/// Default Hive Server port
static const char* DEFAULT_PORT     = "10000";
/// Default connection socket type
static const char* DEFAULT_FRAMED   = "1";

/// Backend Server types
static const char* TYPE_HIVE_SERVER   = "HiveServer";
static const char* TYPE_HIVE_SERVER2_NONSASL   = "HS2NoSasl";
static const char* TYPE_HIVE_SERVER2   = "HiveServer2";
static const char* TYPE_BW_SERVER   = "Beeswax";
static const char* TYPE_SEC_BW_SERVER   = "SecBeeswax";
static const char* KERBEROS_AUTH_TYPE = "GSSAPI";
static const char* PLAIN_AUTH_TYPE = "plain";


/// User name
static const char* DEFAULT_USER = "hive";
static const char* DEFAULT_PASSWORD = "anonymous";

#define TYPEINFO_RESULT_SIZE 8
#define NUM_ODBC2_COLS   15  /* ODBC 2.0 resultset for SQLGetTypeInfo() will have 15 columns */
#define NUM_ODBC3_COLS   19  /* ODBC 3.0 resultset for SQLGetTypeInfo() will have 19 columns */
#define PKEYS_NUM_COLS   6
 
/**
 * Enumeration of known Hive data types
 */
enum HiveType
{
  HIVE_VOID_TYPE,
  HIVE_BOOLEAN_TYPE,
  HIVE_TINYINT_TYPE,
  HIVE_SMALLINT_TYPE,
  HIVE_INT_TYPE,
  HIVE_BIGINT_TYPE,
  HIVE_FLOAT_TYPE,
  HIVE_DOUBLE_TYPE,
  HIVE_STRING_TYPE,
  HIVE_DATE_TYPE,
  HIVE_DATETIME_TYPE,
  HIVE_TIMESTAMP_TYPE,
  HIVE_LIST_TYPE,
  HIVE_MAP_TYPE,
  HIVE_STRUCT_TYPE,
  HIVE_UNKNOWN_TYPE
};

/**
 * Enumeration of Hive return values
 */
enum HiveReturn
{
  HIVE_SUCCESS,
  HIVE_ERROR,
  HIVE_NO_MORE_DATA,
  HIVE_SUCCESS_WITH_MORE_DATA,
  HIVE_STILL_EXECUTING,
  HIVE_TIMEOUT,
  HIVE_NETWORK_ERROR
};

/* Error information from Hive server */
typedef struct _hive_err_info {
  char    err_buf[MAX_HIVE_ERR_MSG_LEN];
  char    sql_state[6];
  int     native_err;
} hive_err_info;

#endif // __hive_constants_h__
